@@ -162,9 +162,11 @@ class ConfigFile(object):
     def _cmp_file(self, source, dest):
         # check exist
         if (os.path.exists(source) and
-                not self.optional and
                 not os.path.exists(dest)):
             return False
+        if (os.path.exists(dest) and
+                not os.path.exists(source)):
+            return False
         # check content
         with open(source, 'rb') as f1, open(dest, 'rb') as f2:
             if f1.read() != f2.read():
